pub struct Method(/* private fields */);Expand description
STUN method.
All STUN messages start with a fixed header that includes a method, a class, and the transaction ID. The method indicates which of the various requests or indications this is;
Implementations